@@ -1,4 +1,7 @@
 from time import sleep
+import gi
+gi.require_version('GLib', '2.0')
+# pylint: disable=wrong-import-position
 from gi.repository import GLib
 
 from ulauncher.api.shared.action.BaseAction import BaseAction
